import { defineStore } from 'pinia';

export const useMapStore = defineStore('mapState', {
    state: () => ({
        map: Object,
        defaultZoom: Number,
        defaultMapCenter: Object,
        currentPlace: Object,
        maxZoom: Number,
        currentZoom: Number,
        duration: 3,
    }),
    actions: {
        zoomToPlace(lat, long) {
            this.map.flyTo([lat, long], this.maxZoom, { duration: this.duration });
            this.currentZoom = this.maxZoom;            
        },
        resetMap() {
            this.map.flyTo(this.defaultMapCenter, this.defaultZoom, { duration: this.duration });
            this.currentZoom = this.defaultZoom;
        },
        lockMap() {
            setTimeout(() => {
                this.map.options.minZoom = this.currentZoom;
                this.map.options.maxZoom = this.currentZoom;
            }, this.duration * 1000 + 100);
            this.map.dragging.disable();
            this.map.touchZoom.disable();
            this.map.doubleClickZoom.disable();
            this.map.scrollWheelZoom.disable();
            this.map.boxZoom.disable();
            this.map.keyboard.disable();
            // map.tap.disable();
          },
          unlockMap() {
            this.map.options.minZoom = this.defaultZoom;
            this.map.options.maxZoom = this.maxZoom;
            this.map.dragging.enable();
            this.map.touchZoom.enable();
            this.map.doubleClickZoom.enable();
            this.map.scrollWheelZoom.enable();
            this.map.boxZoom.enable();
            this.map.keyboard.enable();
            // map.tap.enable();
          },
    },
});